encode_app_error

Function encode_app_error 

pub fn encode_app_error(
    payload: &AppErrorPayload<'_>,
    out: &mut [u8],
) -> Result<usize, WireError>
Encode an AppErrorPayload into out, returning the number of bytes written.

Errors

Returns WireError::SerdeError if the payload does not fit in out.